@@ -354,7 +354,7 @@ fitSpecificTBATS <- function(y, use.box.cox, use.beta, use.damping, seasonal.per
 	#Get the likelihood
 	likelihood <- optim.like$value
 	#Calculate the AIC
-	aic <- likelihood+2*length(param.vector$vect)
+	aic <- likelihood+2*(length(param.vector$vect)+nrow(x.nought))
 	
 	
 	#Make a list object
